checkRequire("Lua_HeroLineupCell");
checkRequire("Lua_ArtifactLineupItem");
Lua_BaseLineupWindow = class("Lua_BaseLineupWindow", Lua_Window);
function Lua_BaseLineupWindow:ctor()
    self:superCall("ctor");

    self.layer = MainWinDefine.NORMAL_WINDOW_LAYER;
    self.isFullSizeWin = true;
    self.isSingleShowWin = true;
    self.showBackBtn = true;

    self.lineupType = Lua_HeroUtil.LINEUP_MAIN_TYPE;
    self.defaultCamp = Lua_HeroUtil.All_TYPE;
    self.positionNum = 5; -- 站位数量
    self.lineupIdx = 1; -- 分队索引
    self.standType = 1; -- 站位类型
end

function Lua_BaseLineupWindow:buildShowItem()
    self:superCall("buildShowItem");
    DataCenter.heroLineupData.isLineuping = true;
    self.connEffX_1 = 0
    self.connEffY_1 = 0
    self.connEffX_2 = -312
    self.connEffY_2 = -42

    self:addLuaEvent("ARTIFACT_SET_COMPLETED", self, self.updateArtifact);
    self:addLuaEvent("LINEUP_HERO_SELECT", self, self.onHeroSelected); -- 英雄选择
    self:addLuaEvent("LINEUP_STANDTYPE_SELECT", self, self.onStandTypeSelected); -- 选择站位更新布阵
    self:addCSharpEvent("CAMP_POSITION_CHANGE", self, self.onHeroCampPosChange); -- 场景移动英雄更新站位
    self:addLuaEvent("HERO_CONNECT_TIPS_CLOSE", self, self.onConnectTipsClose);

    self.heroList = Lua_DragList.new(self.bottomObject, 625, 280, Lua_AxisDefine.Vertical);
    self.heroList:setLocation(0, 355);
    self.heroList.canLongPress = true;
    self.heroList.longPressLimit = 0.4;
    self.heroList.tweenId = 2006;
    self.heroList:setListCell(Lua_HeroLineupCell, 107, 107, 5);
    self.heroList:setCellSpacing(22.5, 15);

    self.campSiftPanel = Lua_CampCareerSiftPanel.new(self.bottomObject);
    self.campSiftPanel:setLocation(0, 153, 0);
    self.campSiftPanel:setArrayData(DataCenter.heroUtil.siftAllInfo);
    self.campSiftPanel:setCallBack(self, self.onCampSelected);

    self.stand_btn:addClickFuntion(self, self.onBtnStandClick);
end

function Lua_BaseLineupWindow:dispose()
    Lua_CommonUtil.removeTimer(self, self.onConnEff1Completed)
    Lua_CommonUtil.removeTimer(self, self.onConnEff2Completed)
    Lua_CommonUtil.removeTimer(self, self.updateGuideDelayHeroLineUp);
    if self.sceneDic ~= nil then
        for k, _ in pairs(self.sceneDic) do
            Scene3DManager.instance:destroyScene(k, 0);
        end
        self.sceneDic = nil;
        self.winSceneId = 0;
    end
    if self.artifactArr then
        self.artifactArr:dispose();
        self.artifactArr:clear();
        self.artifactArr = nil;
    end
    if self.campSiftPanel then
        self.campSiftPanel:dispose();
        self.campSiftPanel = nil;
    end
    if self.heroList ~= nil then
        self.heroList:dispose();
        self.heroList = nil;
    end
    if self.posEffIdsArr ~= nil then
        self.posEffIdsArr:clear();
        self.posEffIdsArr = nil;
    end
    if self.lineupArr then
        self.lineupArr:dispose()
        self.lineupArr:clear()
        self.lineupArr = nil
    end
    if self.connEff1 then
        self.connEff1:dispose()
        self.connEff1 = nil
    end
    if self.connEff2 then
        self.connEff2:dispose()
        self.connEff2 = nil
    end
    self.modelIdsDic = nil;
    self.standTypeDic = nil;
    self.heroDic = nil;
    self.artifactDic = nil;
    if self.data then
        self.data:initLocalInfo()
    end
    self.data = nil
    self:superCall("dispose");
    DataCenter.heroLineupData.isLineuping = false;
end

function Lua_BaseLineupWindow:showWin(param)
    self:superCall("showWin", param)
    self:updateShowInfo(param)
end

function Lua_BaseLineupWindow:updateShowInfo(param)

end

-- 布阵场景
function Lua_BaseLineupWindow:showSceneByLineupType(lineupType)
    if lineupType == nil then
        return;
    end

    if self.sceneDic == nil then
        self.sceneDic = {};
    end
    local sceneId = DataCenter.heroLineupData:getLineUpSceneId(lineupType)
    self.sceneDic[sceneId] = 1;
    self:setWinSceneId(sceneId);
end

-- 布阵场景
function Lua_BaseLineupWindow:showSceneByTemplateId(templateId)
    if templateId == nil then
        return;
    end

    if self.sceneDic == nil then
        self.sceneDic = {};
    end
    local sceneId = DataCenter.heroLineupData:getFightLineupSceneId(templateId);
    self.sceneDic[sceneId] = 1;
    self:setWinSceneId(sceneId);
end

-- 更新布阵信息
function Lua_BaseLineupWindow:updateLineupInfo()
    self.data = DataCenter.heroLineupData:getLineupVo(self.lineupType);
    self.data:checkHeroConnect(self.lineupIdx, false, true);

    self.standTypeDic = self.data.standTypeDic
    self.heroDic = self.data.heroDic
    self.artifactDic = self.data.artifactDic

    self:updateStandInfo();
    self:updateScenePosEff();
    self:updateSceneModel();
    self:updateArtifact();
    self:updateLineupNum();
    
    -- 引导
    self:checkWinGuide();
    Lua_MsgUtil.callFunc("LineUp_LocationInfo_Update", self.data.id);
end

-- 更新站位信息
function Lua_BaseLineupWindow:updateStandInfo()
    self.sceneStandType = nil
    self.standType = self.data:getStandType(self.lineupIdx)
	
    local data = DataCenter.heroLineupUtil:getStandInfoByType(self.standType);
    self.stand_btn:setAltas("hero_embattle", data.stand_icon);
    self.stand_name.text = data.name
end

-- 更新站位特效
function Lua_BaseLineupWindow:updateScenePosEff()
    if self.winSceneId == nil or self.winSceneId <= 0 then
        return;
    end

    if self.sceneStandType == self.standType then
        return;
    end
    self.sceneStandType = self.standType;

    if self.posEffIdsArr == nil then
        self.posEffIdsArr = Array();
    end
    
    local vo = DataCenter.heroLineupData:getLineupVo(self.lineupType)
    local list = DataCenter.heroLineupUtil:getStandListByType(self.standType);
    self.positionNum = #list;
    local idx;
    local data;
    self.showIdxList = {};--展示的站位
    for i = 1, self.positionNum do
        idx = list[i];
        self.showIdxList[idx] = 1;
        if ThingUtil.instance:hasThingById(self.winSceneId, 0, idx) == true then
            ThingUtil.instance:showPlayer(self.winSceneId, 0, idx);
        else
            data = SceneEffectData();
            data.roleId = idx;
            data.sceneId = self.winSceneId;
            data.kind = Lua_ThingDefine.SCENE_EFFECT;
            data.px = Lua_FightCampPosConfig.getConfigData(vo.campposId):getPosxByIdx(Lua_FightDefine.FIGHT_ATTACKER, idx);
            data.py = 0;
            data.pz = Lua_FightCampPosConfig.getConfigData(vo.campposId):getPoszByIdx(Lua_FightDefine.FIGHT_ATTACKER, idx);
            data.canBeClick = false;
            data.effectFile = "buzhen_guangquan_01";
            data.effectName = "buzhen_guangquan_01";
            data.showShadow = false;
            data.isShowName = false;
            data.toLand = false;
            data.rotX = 0;
            data.rotY = 0;
            data.rotZ = 0;
            data.scaX = 1;
            data.scaY = 1;
            data.scaZ = 1;
            ThingUtil.instance:addSceneEffect(data, true);
            self.posEffIdsArr:add(idx);
        end
    end
    self:hidePosEff()
end

function Lua_BaseLineupWindow:hidePosEff()
    if self.posEffIdsArr == nil or self.showIdxList == nil then
        return;
    end

    local len = self.posEffIdsArr:getSize();
    local roleId;
    for i = 1, len do
        roleId = self.posEffIdsArr[i];
        if self.showIdxList[roleId] == nil then
            ThingUtil.instance:hidePlayer(self.winSceneId, 0, roleId);
        end
    end
end

function Lua_BaseLineupWindow:onWinSceneLoaded(sceneId)
    if sceneId == self.winSceneId then
        self:hidePosEff();
    end
end

function Lua_BaseLineupWindow:updateSceneModel()
    if self.data == nil then
        return
    end

    local tab = {}
    local arr = self.data:getHeroArr(self.lineupIdx)
    for i = 1, arr:getSize() do
        if arr[i] > 0 then
            tab[i] = DataCenter.heroData:getItemByUniqueId(arr[i]);
        end
    end
    self:showSceneModel(tab);
end

function Lua_BaseLineupWindow:showSceneModel(tab)
    if self.winSceneId == nil or self.winSceneId <= 0 then
        return;
    end

    if tab == nil then
        if self.modelIdsDic ~= nil and self.modelIdsDic[self.winSceneId] ~= nil then
            self.modelIdsDic[self.winSceneId] = nil;
        end
        ThingUtil.instance:removeAll(self.winSceneId, 0, Lua_ThingDefine.HERO);
        return;
    end

    if self.modelIdsDic == nil then
        self.modelIdsDic = {};
    end
    if self.modelIdsDic[self.winSceneId] == nil then
        self.modelIdsDic[self.winSceneId] = {};
    end

    local vo = DataCenter.heroLineupData:getLineupVo(self.lineupType)
    local list = {};
    local uid;
    local data;
    local modelPosX;
    local modelPosY;
    local modelPosZ;
    local heroModel;
    for stand, heroVo in pairs(tab) do
        uid = heroVo.unique_id;
        list[uid] = 1;
        self.modelIdsDic[self.winSceneId][uid] = 1;

        modelPosX = Lua_FightCampPosConfig.getConfigData(vo.campposId):getPosxByIdx(Lua_FightDefine.FIGHT_ATTACKER, stand);
        modelPosY = 0;
        modelPosZ = Lua_FightCampPosConfig.getConfigData(vo.campposId):getPoszByIdx(Lua_FightDefine.FIGHT_ATTACKER, stand);
        heroModel = DataCenter.thingData:getThingPlayer(self.winSceneId, 0, uid);

        if heroModel ~= nil then
            heroModel.player:setPosPoint(modelPosX, modelPosY, modelPosZ, true);
            heroModel.player.shenbingId = heroVo.weapon_id;
            data = heroModel.player.data;
            data.formationPos = stand;
            data.campPosId = 0;
            data.standType = self.standType;
            data.shenbingId = heroVo.weapon_id;
            data:refreshShowPos();
        else
            data = HeroData();
            data.kind = Lua_ThingDefine.HERO;
            data.isShowName = true;
            data.isShowHpBar = false;
            data.isShowBuffIcon = false;
            data.canBeClick = true;
            data.roleId = uid;
            data.objId = heroVo.id;
            data.formationPos = stand;
            data.campPosId = 0;
            data.standType = self.standType;
            data.lvl = heroVo.level;
            data.hp = 1;
            data.maxHp = 1;
            data.sceneId = self.winSceneId;
            -- data.fashion_id = tonumber(tostring(heroVo.clothes_id));
            data.dir = 90;
            data.px = modelPosX;
            data.py = modelPosY;
            data.pz = modelPosZ;
            data.canDrag = true;
            data.showShadow = false;
            data.bPlanarShadow = false;
            data.toLand = false;
            data.isUIHeadInfo = true;
            data.shenbingId = heroVo.weapon_id;
            data:refreshShowPos();
            ThingUtil.instance:addAnimal(data, true);
        end
    end

    local dic = self.modelIdsDic[self.winSceneId];
    for rid, val in pairs(dic) do
        if list[rid] == nil then--存在和当前阵容不一样的UID就移除掉
            dic[rid] = nil;
            ThingUtil.instance:removeThing(self.winSceneId, 0, rid);
        end
    end
end

-- 更新神器
function Lua_BaseLineupWindow:updateArtifact()
    if self.artifactArr == nil then
        self.artifactArr = Array()
    end
    local list = DataCenter.artifactUtil.unlock_level
    local item
    for i = 1, #list do
        item = self.artifactArr[i]
        if item == nil then
            item = Lua_ArtifactLineupItem.new(self.bottomObject)
            item.content.name = "Lua_ArtifactLineupItem"..i;
            self.artifactArr:add(item)
        end
        item:setScale(0.83, 0.83, 1)
        item:setLocation(-325 + (i - 1) * 65, 550, 0)
        item:setData(i, list[i], self.artifactDic, self.lineupIdx)
        item:setClick(self, self.onArtifactSet)
    end
    self:updateAureoleInfo();
end

function Lua_BaseLineupWindow:onArtifactSet()
    Lua_WindowUtil.openWin("Lua_ArtifactSetWindow", Lua_WinParam.ACTION_OPEN, self.artifactDic[self.lineupIdx])
end

-- 更新上阵数量
function Lua_BaseLineupWindow:updateLineupNum()

end

-- 更新己方光环
function Lua_BaseLineupWindow:updateAureoleInfo()

end

-- 更新阵营选择
function Lua_BaseLineupWindow:onCampSelected(campType, careerType)
    self.selectedCampType = campType;
    self.selectedCareer = careerType;
    self:updateHeroList();
end

function Lua_BaseLineupWindow:updateHeroList()
    local arr = DataCenter.heroLineupData:getHeroList(self.selectedCampType, self.selectedCareer, self.lineupType, self.lineupIdx);
    self.heroList.customParam = self.lineupType * 10000 + self.lineupIdx * 100
    self.heroList:setArrayData(arr);
    self.heroList:moveToIndex(1, true);
    self:showNone(arr == nil or arr:getSize() <= 0);
end

function Lua_BaseLineupWindow:showNone(bShow)
    if bShow then
        if self.noneIcon == nil then
            self.noneIcon = UICreate.createImage(self.bottomObject, "/images/common/xui_common_widget_029.png", 4.5, 375, 0, 0);

            self.noneText = UICreate.createLabel(self.bottomObject, nil, 119, 413.5, 100, 40, 28);
            self.noneText.pivotValue = 4;
            self.noneText.fontName = Lua_MyUISettings.huakangFontName;
            self.noneText.alignmentValue = 4;
            self.noneText.horizontalOverflowValue = 1;
            self.noneText.colorStr = Lua_ColorDefine.transColorStr("616161");
            self.noneText:setLangValue(126318);
        end
        self.noneIcon:setEnable(true);
        self.noneText:setEnable(true);
    else
        if self.noneIcon ~= nil then
            self.noneIcon:setEnable(false);
            self.noneText:setEnable(false);
        end
    end
end

function Lua_BaseLineupWindow:onHeroSelected(heroVo)
    local standIdx = self.data:getHeroStandIdx(heroVo.unique_id)
    if standIdx == nil then -- 未上阵
        standIdx = DataCenter.heroLineupData:getNullStandIdx(self.standType, self.heroDic, self.lineupIdx)
        if standIdx == nil then -- 上阵英雄已达上限
            OperateAlert.showLangValue(126300)
            return
        end

        local lineupIdx = self.data:getHeroLineupIdx(heroVo.id)
        if lineupIdx then
            if lineupIdx == self.lineupIdx then
                OperateAlert.showLangValue(126302)
            else
                OperateAlert.show(LanUtil.formateStr(126325, convert_arab_to_chinese(lineupIdx)))
            end
            return
        end

        self.data:setHeroById(self.lineupIdx, standIdx, heroVo.unique_id)
    else
        self.data:setHeroById(self.lineupIdx, standIdx, 0)
    end

    self:updateHeroSelected();
    self:updateSceneModel();
    self:updateLineupNum();
    self:updateAureoleInfo();

    -- 引导
    self:checkWinGuide();
    Lua_MsgUtil.callFunc("LineUp_LocationInfo_Update", self.data.id);
end

function Lua_BaseLineupWindow:updateHeroSelected()
    local showList = self.heroList.showList;
    for i = 1, showList:getSize() do
        showList[i]:updateSelected();
    end
    self.data:checkHeroConnect(self.lineupIdx, true, true);
    DataCenter.heroLineupData:checkConnPopupWin()
end

-- 选择站位
function Lua_BaseLineupWindow:onStandTypeSelected(standType)
    if self.standType == standType then
        return;
    end
    local prev_standType = self.standType;
    self.standType = standType;
    self.data:setStandType(self.lineupIdx, standType);

    DataCenter.heroLineupData:updateStandByType(self.heroDic, self.lineupIdx, prev_standType, standType);
    self:updateStandInfo();
    self:updateScenePosEff();
    self:updateSceneModel();

    -- 引导
    self:checkWinGuide();
    Lua_MsgUtil.callFunc("LineUp_LocationInfo_Update", self.data.id);
end

function Lua_BaseLineupWindow:onHeroCampPosChange(uid)
    uid = tonumber(tostring(uid));
    local heroModel = DataCenter.thingData:getThingPlayer(self.winSceneId, 0, uid);
    if heroModel == nil then
        return;
    end

    local new_stand = heroModel.data.formationPos;
    -- if DataCenter.heroLineupData:checkStandIdxIsLock(self.standType, new_stand) then
    --     return
    -- end

    DataCenter.heroLineupData:updateStandChange(self.lineupType, self.lineupIdx, uid, new_stand, self.winSceneId, self.standType);
    self:updateHeroSelected();
    self:updateLineupNum();
    self:updateSceneModel();
    self:updateAureoleInfo();
    self.data:initLineUpInfo();

    -- 引导
    self:checkWinGuide();
    Lua_MsgUtil.callFunc("LineUp_LocationInfo_Update", self.data.id);
end

-- 阵法
function Lua_BaseLineupWindow:onBtnStandClick(go)
    Lua_WindowUtil.openWin("Lua_HeroLineupStandWindow", Lua_WinParam.ACTION_OPEN, self.standType);
end

-- 分队选项
function Lua_BaseLineupWindow:createTeamButton(teamNum)
    if self.lineupArr == nil then
        self.lineupArr = Array()
    end
    local len = self.lineupArr:getSize()
    len = teamNum - len

    local item
    while len > 0 do
        item = Lua_LineupUnitItem.new(self.bottomObject)
        self.lineupArr:add(item)
        len = len - 1
    end

    while len < 0 do
        item = self.lineupArr:remove(1)
        item:dispose()
        len = len + 1
    end

    len = self.lineupArr:getSize()
    local space = 60
    local w = -(space * len) / 2 + space / 2
    for i = 1, len do
        item = self.lineupArr[i]
        item:setLocation(((i - 1) % len) * space + w, 555, 0)
        item:setData(i, self, self.onTeamSelected)
        item:setSelected(self.lineupIdx)
    end
end

function Lua_BaseLineupWindow:onTeamSelected(lineupIdx, bUpdate)
    if self.lineupIdx == lineupIdx and bUpdate ~= true then
        return
    end
    self.lineupIdx = lineupIdx

    self.data:checkHeroConnect(self.lineupIdx, false, true);
    self:updateStandInfo();
    self:updateScenePosEff();
    self:updateSceneModel();
    self:updateArtifact();
    self:updateLineupNum();
    self:updateAureoleInfo();
    self.campSiftPanel:setSelected(self.defaultCamp, 0, true)
    for i = 1, self.lineupArr:getSize() do
        self.lineupArr[i]:setSelected(lineupIdx)
    end
    if self.updateEnemyInfo ~= nil then
        self:updateEnemyInfo()
    end
end

function Lua_BaseLineupWindow:checkIsChange(lineupIdx)
    if self.lineupArr == nil then
        lineupIdx = lineupIdx or self.lineupIdx
        return self.data:checkLineupIsChange(lineupIdx)
    else -- 开启了多队
        for i = 1, self.data.team_number do
            if self.data:checkLineupIsChange(i) then
                return true
            end
        end
    end
    return false
end

function Lua_BaseLineupWindow:onSaveLineup(lineupType)
    lineupType = lineupType or self.lineupType
    Lua_ProxyManager.getProxy("Lua_HeroProxy"):sHeroSaveLineup(lineupType, self.data.standTypeDic, self.data.heroDic, self.data.artifactDic);
end

function Lua_BaseLineupWindow:onCheckArtifact()
    local value = false
    if self.lineupArr == nil then
        value = self:checkArtifact(self.lineupIdx);
    else
        for i = 1, self.data.team_number do
            if self:checkArtifact(i) then
                value = true;
                break;
            end
        end
    end
    if value then
        local tipsData = { des = 126316, posY = 30, neverTip = Lua_NeverTipDefine.ARTIFACE_SET,
            btnType = 1, sureLabel = 126329, owner = self, cancelFun = self.onCheckLineup, sureFun = self.onArtifactSet
        };
        Lua_WindowUtil.openWin("Lua_TipsWindow", Lua_WinParam.ACTION_OPEN, tipsData);
    else
        self:onCheckLineup();
    end
end

function Lua_BaseLineupWindow:checkArtifact(lineupIdx)
    if DataCenter.neverTipData:getNeverValue(Lua_NeverTipDefine.ARTIFACE_SET) then
        return false;
    else
        local artifactId = DataCenter.heroLineupData:getUnWearArtifact(self.artifactDic, lineupIdx);
        if artifactId == nil then
            return false;
        end

        local arr = self.artifactDic[self.lineupIdx]
        local list = DataCenter.artifactUtil.unlock_level
        for i = 1, #list do
            if DataCenter.roleData.level >= list[i] then
                if arr[i] == 0 then
                    return true;
                end
            end
        end
    end
    return false;
end

function Lua_BaseLineupWindow:onCheckLineup()
    if self.lineupArr == nil then
        if self:checkLineupNum(self.lineupIdx) then
            return;
        end
        if self:checkLineupIsFull(self.lineupIdx) then
            return;
        end
    else
        for i = 1, self.data.team_number do
            if self:checkLineupNum(i) then
                return;
            end
        end
        for i = 1, self.data.team_number do
            if self:checkLineupIsFull(i) then
                return;
            end
        end
    end
    self:onFight();
end

function Lua_BaseLineupWindow:checkLineupNum(lineupIdx)
    local num = self.data:getHeroNumByLineupIdx(lineupIdx);
    if num == 0 then
        if lineupIdx > 1 then
            OperateAlert.show(LanUtil.formateStr(126326, convert_arab_to_chinese(lineupIdx)));
        else
            OperateAlert.showLangValue(126307);
        end
        return true;
    elseif num == 1 then
        local arr = self.data:getHeroArr(lineupIdx);
        local heroVo;
        for i = 1, arr:getSize() do
            if arr[i] > 0 then
                heroVo = DataCenter.heroLineupData:getHeroVo(self.lineupType, arr[i]);
                if heroVo.trial_state then
                    OperateAlert.showLangValue(126330);
                    return true;
                end
            end
        end
    end
    return false;
end

function Lua_BaseLineupWindow:checkLineupIsFull(lineupIdx)
    local num = self.data:getHeroNumByLineupIdx(lineupIdx);
    if num < self.positionNum and DataCenter.heroLineupData:checkPackHaveHero(self.lineupType) then
        local tipsData = { des = 126312, btnType = 1, cancelLabel = 126328, owner = self, sureFun = self.onFight };
        Lua_WindowUtil.openWin("Lua_TipsWindow", Lua_WinParam.ACTION_OPEN, tipsData);
        return true;
    end
    return false;
end

function Lua_BaseLineupWindow:onFight()

end

function Lua_BaseLineupWindow:onConnectTipsClose()
    if self.connEff1 == nil then
        self.connEff1 = UICreate.createUIEffect(self.content, nil, nil, 0, 0)
        self.connEff1.anchorValue = 4
        local scale = string.format("%.1f", self.height / MainWinDefine.DEFAULT_SHOW_HEIGHT)
        self.connEff1:setScale(1, scale, 1)
        self.connEff1:setLocation(self.connEffX_1, self.connEffY_1, 0)
        self.connEff1:addLuaLoadCompleteFun(self, self.onConnEffLoaded)
        self.connEff1:setUrl("/effects/uiEffects/ui_lx_bz_0102", "ui_lx_bz_0102")
    else
        self.connEff1:setEnable(false)
        self:onConnEffLoaded()
    end
end

function Lua_BaseLineupWindow:onConnEffLoaded()
    self.connEff1:setEnable(true)
    Lua_CommonUtil.delayCall(0.75, self, self.onConnEff1Completed)
    Lua_CommonUtil.delayCall(0.5, self, self.onConnEff2Completed)
end

function Lua_BaseLineupWindow:onConnEff1Completed()
    self.connEff1:setEnable(false)
    if self.connEff2 == nil then
        self.connEff2 = UICreate.createUIEffect(self.content, "/effects/uiEffects/ui_lx_bz_0101", "ui_lx_bz_0101", 0, 0)
        self.connEff2.anchorValue = 1
        self.connEff2:setScale(1, 1, 1)
        self.connEff2:setLocation(self.connEffX_2, self.connEffY_2, 0)
    else
        self.connEff2:setEnable(false)
        self.connEff2:setEnable(true)
    end
end

function Lua_BaseLineupWindow:onConnEff2Completed()
    if not DataCenter.heroLineupData:checkConnPopupWin() then
        Lua_WindowUtil.openWin("Lua_HeroConnectTipsWindow", Lua_WinParam.ACTION_CLOSE)
    end
end

-- 检测引导数据
function Lua_BaseLineupWindow:checkWinGuide()
    -- print("Lua_BaseLineupWindow:checkWinGuide()")
    self:superCall("checkWinGuide");
end

-- 引导同步
function Lua_BaseLineupWindow:updateGuide(guideId, info)
    -- print("Lua_BaseLineupWindow updateGuide", guideId, info == nil, self.data == nil)
    if info == nil or self.data == nil then
        return;
    end

    local operateVal = info.operateVal; -- 操作行为参数
    -- print("操作行为参数operateVal = ", operateVal);
    if operateVal == nil then
        return;
    end

    local heroId = tonumber(info.heroId);
    if operateVal == 1 then -- 上阵
        local lineIdx, standIdx = self.data:getHeroStandIdxById(heroId);
        if standIdx == nil then -- 找到背包列表的对应item
            
        else -- 已上阵完成
            DataCenter.guideCommonData.winGuideResult = 1;
            Lua_MsgUtil.callFunc("Guide_WinSync_Complete", guideId);
        end
    elseif operateVal == 2 then -- 交换位置
        local lineIdx, standIdx = self.data:getHeroStandIdxById(heroId);
        -- print("交换位置", heroId, lineIdx, standIdx, info.stand);
        if standIdx ~= nil then
            local stand = info.stand;
            if stand ~= nil then -- 目标位置
                if stand == standIdx then -- 完成
                    DataCenter.guideCommonData.winGuideResult = 1;
                    Lua_MsgUtil.callFunc("Guide_WinSync_Complete", guideId);
                else
                    -- 获取场景对应英雄
                    local uid = self.data:getHeroUidByStandIdx(lineupIdx, standIdx);
                    if uid > 0 then
                        if standIdx == 4 then
                            local params = { posType = 2, posX = 110.5, posY = 91.56, angle = 149.8, effectPosX = -74, effectPosY = -51, effectRotZ = 68, offsetPanelX = 130, offsetPanelY = 0};
                            DataCenter.guideCommonData.guideClickObjMaskParams = params;
                        end
                        DataCenter.guideCommonData.guideClickObjPath = DataCenter.guideUtil:getSceneObjPath(self.winSceneId, nil, uid);
                        DataCenter.guideCommonData.guideSceneId = self.winSceneId; -- 场景
                        -- print("获取场景对应英雄", self.winSceneId, DataCenter.guideCommonData.guideClickObjPath);
                        Lua_MsgUtil.callFunc("Guide_WinSync_Complete", guideId);
                    end
                end
            else -- 无条件,完成
                DataCenter.guideCommonData.winGuideResult = 1;
                Lua_MsgUtil.callFunc("Guide_WinSync_Complete", guideId);
            end
        end
    elseif operateVal == 3 then -- 英雄列表定位
        local delayCheckTime = DataCenter.guideUtil:getWinTweenTime(self.windowName) + 0.1;
        local param = {heroId = heroId, guideId = guideId};
        -- self:updateGuideDelayHeroLineUp(param);
        Lua_CommonUtil.delayCall(delayCheckTime, self, self.updateGuideDelayHeroLineUp, param);
    end
end

function Lua_BaseLineupWindow:updateGuideDelayHeroLineUp(param)
    local heroId, guideId = param.heroId, param.guideId;
    if heroId ~= nil then
        local lineIdx, standIdx = self.data:getHeroStandIdxById(heroId);
        if standIdx ~= nil then
            DataCenter.guideCommonData.winGuideResult = 1;
            Lua_MsgUtil.callFunc("Guide_WinSync_Complete", guideId);
        else
            local arr = self.heroList.showDragDataList;
            local heroCellId;
            local heroItem;
            local index;
            for i = 1, arr:getSize() do
                heroItem = arr:getItem(i).cell;
                heroCellId = heroItem.data and heroItem.data.id or 0;
                if heroCellId == heroId then
                    self.heroList.canDrag = false;
                    self.heroList.canLongPress = false;
                    DataCenter.guideCommonData.antiRepeatClick = false;
                    DataCenter.guideCommonData.guideClickObjTarget = heroItem.content;
                    Lua_MsgUtil.callFunc("Guide_WinSync_Complete", guideId);
                    break;
                end
            end
        end
    end
end



















Lua_LineupUnitItem = class("Lua_LineupUnitItem", Lua_DisplayObject);
function Lua_LineupUnitItem:ctor(p)
    self:superCall("ctor", p);
end

function Lua_LineupUnitItem:buildShowItem()
    self:superCall("buildShowItem");
    
    self.teamIcon = UICreate.createUIAtlasImage(self.content, nil, nil, 0, 0, 0, 0)
    self.teamIcon:addClickFuntion(self, self.onClick)
    self.selectedIcon = UICreate.createUIAtlasImage(self.content, "hero_embattle", "xui_bz_button_17_n", 0, 0, 0, 0)
end

function Lua_LineupUnitItem:dispose()
    self.owner = nil
    self.callBack = nil
    self:superCall("dispose");
end

function Lua_LineupUnitItem:setData(teamIdx, owner, callBack)
    self.lineupIdx = teamIdx
    self.owner = owner
    self.callBack = callBack
    self.teamIcon:setAltas("hero_embattle", "xui_bz_button_"..(13 + teamIdx).."_n")
end

function Lua_LineupUnitItem:setSelected(teamIdx)
    self.selectedIcon:setEnable(teamIdx == self.lineupIdx)
end

function Lua_LineupUnitItem:onClick(go)
    if self.owner and self.callBack then
        self.callBack(self.owner, self.lineupIdx);
        return
    end   
end