-- 边境远征 布阵
checkRequire("Lua_BaseLineupWindow");
checkRequire("Lua_FightLineupConnectItem");
Lua_ExpeditionLineupWindow = class("Lua_ExpeditionLineupWindow", Lua_BaseLineupWindow);
function Lua_ExpeditionLineupWindow:ctor()
	self:superCall("ctor");

	self.windowName = "Lua_ExpeditionLineupWindow";
	self.skinName = "FightLineupWindow_skin";
end

function Lua_ExpeditionLineupWindow:buildShowItem()
	self:superCall("buildShowItem");
    self.connEffX = -312
    self.connEffY = -42
	self.limitDic = {};

    self.attackerConnectItem = Lua_FightLineupConnectItem.new(self.topObject)
    self.attackerConnectItem:setLocation(-312, -41, 0)

    self.defenderConnectItem = Lua_FightLineupConnectItem.new(self.topObject, 2)
    self.defenderConnectItem:setLocation(312, -41, 0)

    self.heroList:setListCell(Lua_ExpeditionLineupHeroItem, 107, 138, 5);
    self.heroList:setCellSpacing(22.5, 0);

    self.btnFight:setLangValue(126305);
	self.btnFight:addClickFuntion(self, self.onBtnSaveClick);
	self.one_btn:setEnable(false);
end

function Lua_ExpeditionLineupWindow:dispose()
    if self.attackerConnectItem then
        self.attackerConnectItem:dispose();
        self.attackerConnectItem = nil;
    end
    if self.defenderConnectItem then
        self.defenderConnectItem:dispose();
        self.defenderConnectItem = nil;
    end
	if self.enemyLineupPanel ~= nil then
		self.enemyLineupPanel:dispose();
		self.enemyLineupPanel = nil;
	end
	self.limitDic = nil;
	self:superCall("dispose");
end

function Lua_ExpeditionLineupWindow:updateShowInfo(param)
	self.lineupType = Lua_HeroUtil.LINEUP_EXPEDITION
	self:showSceneByLineupType(self.lineupType)

	local len = #param.def_lineup_list
	if len > 1 then
		local info
		local blood
		local selectIdx
		for i = 1, len do
			info = param.def_lineup_list[i]
			blood = 0;
			for j = 1, #info.hero_list do
				blood = blood + info.hero_list[j].blood
			end
			if selectIdx == nil and blood > 0 then
				selectIdx = i
			end
			if blood <= 0 then
				self.limitDic[i] = 1
			end
		end
		self.lineupIdx = selectIdx or 1;

		self:createTeamButton(len)
	end

	self:updateLineupInfo()
	self.data:initLineUpInfo()
	self:updateEnemyInfo()
	self:updateHeroInfo()
end

function Lua_ExpeditionLineupWindow:updateEnemyInfo()
	local list = self.showData.def_lineup_list[self.lineupIdx]
	if list then
		-- local aureole_list = DataCenter.heroLineupData:getAureoleInfoByHeroList(list.hero_list);
		-- local aureole_id = DataCenter.heroLineupUtil:getAureoleId(aureole_list);
		self.defenderConnectItem:setData(self.showData.name, list.force);
		self:updateEnemyLineup(2, list.hero_list);
	end
end

function Lua_ExpeditionLineupWindow:updateHeroInfo()
	self.campSiftPanel:setSelected(self.defaultCamp, 0, true);
	self:updateSceneModel();
	self:updateAureoleInfo();
end

function Lua_ExpeditionLineupWindow:updateHeroList()
	local arr = DataCenter.expeditionData:getHeroList(self.lineupType, self.selectedCampType, self.selectedCareer);
	local key = self.lineupArr == nil and 1 or 0
	self.heroList.customParam = self.lineupType * 10000 + self.lineupIdx * 100 + key
	self.heroList:setArrayData(arr);
	self.heroList:moveToIndex(1, true);
	self:showNone(arr == nil or arr:getSize() <= 0);
end

function Lua_ExpeditionLineupWindow:updateSceneModel()
	if self.heroDic == nil or self.lineupIdx == nil then
		return;
	end

	local tab = {};
    local arr = self.heroDic[self.lineupIdx]
    for i = 1, arr:getSize() do
        if arr[i] > 0 then
            tab[i] = DataCenter.expeditionData:getLineupHeroVo(arr[i]);
        end
    end
	self:showSceneModel(tab);
end

-- 己方光环更新
function Lua_ExpeditionLineupWindow:updateAureoleInfo()
    local force = DataCenter.heroLineupData:calcLineupForce(self.lineupType, self.lineupIdx);
    self.attackerConnectItem:setData(DataCenter.roleData.name, force);
    self.attackerConnectItem:setLineup(self.lineupType, self.lineupIdx)
end

-- 九宫格数据更新
function Lua_ExpeditionLineupWindow:updateEnemyLineup(dataType, list)
	if self.enemyLineupPanel == nil then
        self.enemyLineupPanel = Lua_HeroGridViewPanel.new(self.content);
        self.enemyLineupPanel:setRectAnchor(1);
        self.enemyLineupPanel:setLocation(204, -209, 0);
        self.enemyLineupPanel:setCanClick(true);
        self.enemyLineupPanel:setLayout(1, 2);
        self.enemyLineupPanel:setGridCell(75, 75, Lua_ExpeditionLineupHeroGridItem);
	end
    if dataType == 1 then -- 配置表数据
        self.defenderConnectItem:setConfig(list, self.lineupIdx);
        self.enemyLineupPanel:setDataByConfig(list, self.lineupIdx);
    elseif dataType == 2 then -- 服务端数据
        self.defenderConnectItem:setProto(list);
        self.enemyLineupPanel:setDataByProto(list);
    end
end

function Lua_ExpeditionLineupWindow:onHeroSelected(heroVo)
	if self.limitDic[self.lineupIdx] == 1 then
		OperateAlert.showLangValue(330043);
		return;
	end

	if DataCenter.expeditionData:checkHeroIsWin(heroVo.id) then
		OperateAlert.showLangValue(330043);
		return;
	end

	self:superCall("onHeroSelected", heroVo);
end

function Lua_ExpeditionLineupWindow:onHeroCampPosChange(uid)
	if self.limitDic[self.lineupIdx] == 1 then
		uid = tonumber(tostring(uid));
		local heroModel = DataCenter.thingData:getThingPlayer(self.winSceneId, 0, uid);
		if heroModel then
			local standIdx = heroModel.data.formationPos
			if standIdx ~= -1 then -- 校正后才弹提示
				OperateAlert.showLangValue(330043);
			end
			standIdx = self.data:getHeroStandIdx(uid)
			DataCenter.heroLineupData:updateStandChange(self.lineupType, self.lineupIdx, uid, standIdx, self.winSceneId, self.standType);
		else
			OperateAlert.showLangValue(330043);
		end
		return;
	end

	if DataCenter.expeditionData:checkHeroIsWin(uid) then
		OperateAlert.showLangValue(330043);
		return;
	end

	self:superCall("onHeroCampPosChange", uid);
end

function Lua_ExpeditionLineupWindow:onBackBtnClick(go)
	if self:checkIsChange() then
		self.needCloseWin = true;
		self:showTipsWindow();
	else
		self:hide();
	end
end

function Lua_ExpeditionLineupWindow:onBtnSaveClick(go)
	if self:checkIsChange() then
		self:onSureFun();
	else
		self:hide();
	end
end

-- 布阵改变提示
function Lua_ExpeditionLineupWindow:showTipsWindow()
	local tipData = { des = 126306, posY = 30, btnType = 1, owner = self, cancelFun = self.hide, sureFun = self.onSureFun };
	Lua_WindowUtil.openWin("Lua_TipsWindow", Lua_WinParam.ACTION_OPEN, tipData);
end

function Lua_ExpeditionLineupWindow:onSureFun()
    if self.lineupArr == nil then
        if self:checkLineupNum(self.lineupIdx) then
            return;
        end
        if self:checkLineupIsFull(self.lineupIdx) then
            return;
        end
    else
        for i = 1, self.data.team_number do
            if self:checkLineupNum(i) then
                return;
            end
        end
        for i = 1, self.data.team_number do
            if self:checkLineupIsFull(i) then
                return;
            end
        end
    end
	self:onSaveLineup();
end

function Lua_ExpeditionLineupWindow:checkLineupNum(lineupIdx)
	if self.limitDic[lineupIdx] ~= 1 then
		local num = self.data:getHeroNumByLineupIdx(lineupIdx)
		if num == 0 then
        if lineupIdx > 1 then
            OperateAlert.show(LanUtil.formateStr(126326, convert_arab_to_chinese(lineupIdx)));
        else
            OperateAlert.showLangValue(126307);
        end
			return true;
		elseif num == 1 then
			local arr = self.data:getHeroArr(lineupIdx);
			local heroVo;
			for i = 1, arr:getSize() do
				if arr[i] > 0 then
					heroVo = DataCenter.heroLineupData:getHeroVo(self.lineupType, arr[i]);
					if heroVo.trial_state then
						OperateAlert.showLangValue(126330);
						return true;
					end
				end
			end
		end
	end
	return false;
end

function Lua_ExpeditionLineupWindow:checkLineupIsFull(lineupIdx)
    local num = self.data:getHeroNumByLineupIdx(lineupIdx);
    if num < self.positionNum and DataCenter.expeditionData:checkPackHaveHero(self.lineupType) then
        local tipsData = { des = 126312, btnType = 1, cancelLabel = 126328, owner = self, sureFun = self.onSaveLineup };
        Lua_WindowUtil.openWin("Lua_TipsWindow", Lua_WinParam.ACTION_OPEN, tipsData);
        return true;
    end
    return false;
end

function Lua_ExpeditionLineupWindow:onSaveLineup()
    self:superCall("onSaveLineup");
	-- if self.needCloseWin == true then
	-- 	self:hide();
	-- end
	self:hide();
end




















Lua_ExpeditionLineupHeroItem = class("Lua_ExpeditionLineupHeroItem", Lua_HeroLineupCell);
function Lua_ExpeditionLineupHeroItem:buildShowItem()
	self:superCall("buildShowItem");

	self.itemIcon:setLocation(0, 7, 0);

	self.hpBar = UICreate.createProgressBar(self.content, "expedition_atlas_1", "ui_bjyz_progress_002_f", "expedition_atlas_1", "ui_bjyz_progress_002_b", 0, -63, 80, 8);
	self.hpBar:setBarOffset(2, 2);
	self.hpBar:setMaxValue(1);
	self.hpBar:setValue(0);
end

function Lua_ExpeditionLineupHeroItem:dispose()
	self.hpBar = nil;
	self:superCall("dispose");
end

function Lua_ExpeditionLineupHeroItem:setData(data)
	self.data = data;
	
	self.itemIcon:setData(data);
	if data.assist == 0 then
		self:showAssistIcon(false);
	else
		self:showAssistIcon(true);
	end
	self:updateSelected();

	self.hpBar:setMaxValue(data.max_blood);
	self.hpBar:setValue(data.blood);
end

function Lua_ExpeditionLineupHeroItem:updateSelected()
	local vo = DataCenter.heroLineupData:getLineupVo(self.curLineupType);
	self.lineupIdx = vo:getHeroLineupIdx(self.data.id)
	self.standIdx = vo:getHeroStandIdx(self.data.unique_id)

	if self.data.blood > 0 then
		self:showDeadIcon(false);
		self:showWinIcon(false);
		if self.lineupIdx == self.curLineupIdx then
			self.itemIcon:setDrawMask(self.standIdx ~= nil)
			self.itemIcon:setMask(false)
			self.itemIcon:showText(0, nil)
		else
			self.itemIcon:setDrawMask(false)
			if self.lineupIdx then
				self.itemIcon:setMask(true)
				self.itemIcon:showText(0, LanUtil.formateStr(126324, convert_arab_to_chinese(self.lineupIdx)))
			else
				if DataCenter.expeditionData:checkHeroIsWin(self.data.id) then
					self.itemIcon:setMask(true)
					self:showWinIcon(true);
				else
					self.itemIcon:setMask(false)
				end
				self.itemIcon:showText(0, nil)
			end
		end
	else
		self.itemIcon:setDrawMask(false);
		self.itemIcon:setMask(true);
		self:showDeadIcon(true);
		self:showWinIcon(false);
	end
end

function Lua_ExpeditionLineupHeroItem:showAssistIcon(bShow)
	if bShow then
		if self.assistIcon == nil then
			self.assistIcon = UICreate.createUIAtlasImage(self.content, "common_altas_3", "ui_bjyz_label_04", 39, -20.5, 0, 0);
		end
		self.assistIcon:setEnable(true);
	else
		if self.assistIcon ~= nil then
			self.assistIcon:setEnable(false);
		end
	end
end

function Lua_ExpeditionLineupHeroItem:showDeadIcon(bShow)
	if bShow then
		if self.deadIcon == nil then
			self.deadIcon = UICreate.createUIAtlasImage(self.content, "expedition_atlas_1", "ui_bjyz_label_05", 0, 6, 0, 0);
		end
		self.deadIcon:setEnable(true);
	else
		if self.deadIcon ~= nil then
			self.deadIcon:setEnable(false);
		end
	end
end

function Lua_ExpeditionLineupHeroItem:showWinIcon(bShow)
	if bShow then
		if self.winIcon == nil then
			self.winIcon = UICreate.createUIAtlasImage(self.content, "hero_embattle", "xui_hx_window_40", 0, 6, 0, 0);
		end
		self.winIcon:setEnable(true);
	else
		if self.winIcon ~= nil then
			self.winIcon:setEnable(false);
		end
	end
end

function Lua_ExpeditionLineupHeroItem:onPressClick()
	if self.data.blood <= 0 then
		OperateAlert.showLangValue(330037);
		return;
	end
    if self.lineupIdx and self.lineupIdx ~= self.curLineupIdx then
        OperateAlert.show(LanUtil.formateStr(126325, convert_arab_to_chinese(self.lineupIdx)))
        return
    end
    Lua_MsgUtil.callFunc("LINEUP_HERO_SELECT", self.data);
end

function Lua_ExpeditionLineupHeroItem:onLongPressClick()
    if Lua_WindowUtil.isWindowShowing("Lua_HeroTipsWindow") == false then
		local heroVo = DataCenter.heroData:getItemByUniqueId(self.data.unique_id);
		if heroVo == nil then
			Lua_ProxyManager.getProxy("Lua_HeroProxy"):sCheckRoleHeroInfo(self.data.unique_id);
		else
			Lua_WindowUtil.openWin("Lua_HeroTipsWindow", Lua_WinParam.ACTION_OPEN, heroVo);
		end
    end
end



















Lua_ExpeditionLineupHeroGridItem = class("Lua_ExpeditionLineupHeroGridItem", Lua_HeroGridViewItem)
function Lua_ExpeditionLineupHeroGridItem:ctor(p)
	self:superCall("ctor", p);
end

function Lua_ExpeditionLineupHeroGridItem:setData(dataType, data)
	self:superCall("setData", dataType, data);
	if data == nil or data.blood > 0 then
		self:showDeadIcon(false);
	else
		self:showDeadIcon(true);
	end
	if self.itemIcon then
		self.itemIcon:setSiblingIndex(1)
	end
end

function Lua_ExpeditionLineupHeroGridItem:showDeadIcon(bValue)
	if bValue then
		if self.deadIcon == nil then
			self.deadMask = UICreate.createUIAtlasImage(self.content, "common_altas_1", "ui_common_window_015", 0, 0, 0, 0);
			self.deadMask:setScale(0.65, 0.65, 1);
			self.deadIcon = UICreate.createUIAtlasImage(self.content, "expedition_atlas_1", "ui_bjyz_label_05", 0, 0, 0, 0);
			self.deadIcon:setScale(0.8, 0.8, 1);
		end
		self.deadIcon:setEnable(true);
		self.deadMask:setEnable(true);
	else
		if self.deadIcon ~= nil then
			self.deadIcon:setEnable(false);
			self.deadMask:setEnable(false);
		end
	end
end