--爬塔布阵
checkRequire("Lua_FightLineupWindow")
Lua_TowerLineupWindow = class("Lua_TowerLineupWindow", Lua_FightLineupWindow);
function Lua_TowerLineupWindow:ctor()
    self:superCall("ctor");
    self.windowName = "Lua_TowerLineupWindow";
end

function Lua_TowerLineupWindow:buildShowItem()
    self:superCall("buildShowItem");
    self:addLuaEvent("TOWER_LINEUP_HERO_SELECT", self, self.onHeroSelected); -- 选择英雄

    self.heroList:setListCell(Lua_TowerLineupCell, 107, 107, 5);
end

function Lua_TowerLineupWindow:dispose()
    self.campLimitDic = nil;
    self.des = nil;
    self:superCall("dispose");
end

function Lua_TowerLineupWindow:updateShowInfo(param)
    -- param.limit_camp; --上阵类型限制
    -- param.id; -- 爬塔类型
    self.stage_id = param.cur_stage_id; -- 关卡id
    self.template_id = param.fight_id; -- 战斗模板id
    self.lineupType = Lua_FightTemplateConfigData.getConfigData(self.template_id).lineup_type;

    local config = DataCenter.climbTowerUtil:getTowerConfig(self.stage_id);--关卡数据
    self.monster_player_id = config.robot
    self.limit_num = config.limit_num; --最大上阵数量

    self.campLimitDic = {}
    local obj;
    for i = 1, #param.limit_camp do
        obj = param.limit_camp[i];
        self.campLimitDic[obj] = 1;
    end
    self.campLimitTips = LanUtil.formateStr(201025, DataCenter.climbTowerUtil:limitCampName(param.limit_camp));

    self:showSceneByTemplateId(self.template_id);
    self:updateLineupInfo();
    self:updateEnemyInfo();
    self.campSiftPanel:setLimitCamp(self.campLimitDic, self.campLimitTips);
    self.campSiftPanel:setSelected(Lua_HeroUtil.All_TYPE, 0);
    self:updatePrompt();
    self:onTrialLimitTip();

    if param.new_step > 0 and param.cur_stage_id >= param.new_step then
        self:createTeamButton(self.data.team_number)
    end
end

function Lua_TowerLineupWindow:updateLineupNum()
    self:superCall("updateLineupNum");
    self:updatePrompt();
    self:onTrialLimitTip();
end

-- 更新条件描述
function Lua_TowerLineupWindow:updatePrompt()
    if self.showData.camp == 0 then
        return
    end

    if self.checkHelp == nil then
        self.checkHelp = UICreate.createUIAtlasImage(self.topObject, "common_altas_1", "ui_common_button_016_n", -320, -215, 0, 0);
    end

    if self.promptText == nil then
        self.promptText = UICreate.createLabel(self.topObject, LanUtil.getValue(126322), -235, -215, 100, 31, 22);
        self.promptText.alignmentValue = 3;
        self.promptText.horizontalOverflowValue = 1;
    end

    self.promptText.text = LanUtil.formateStr(201024, tostring(self.limit_num), DataCenter.climbTowerUtil:limitCampName(self.showData.limit_camp));
    local num = self.data:getHeroNumByLineupIdx(self.lineupIdx)
    if num < self.limit_num then
        self.promptText.colorStr = Lua_ColorDefine.transColorStr("F63C3C")
    else
        self.promptText.colorStr = Lua_ColorDefine.transColorStr("59CD20")
    end
end

-- 更新筛选状态
function Lua_TowerLineupWindow:onCampSelected(campType, careerType)
    if campType ~= 0 and self.campLimitDic[campType] == nil then
        OperateAlert.show(self.campLimitTips);
        return;
    end
    
    self:superCall("onCampSelected", campType, careerType);
end

function Lua_TowerLineupWindow:updateHeroList()
    local arr = DataCenter.heroLineupData:getHeroListByCampDic(self.selectedCampType, self.selectedCareer, self.campLimitDic, self.lineupType, self.lineupIdx);
    self.heroList.customParam = self.lineupType * 10000 + self.lineupIdx * 100 + self.showData.id;
    self.heroList:setArrayData(arr);
    self.heroList:moveToIndex(1, true);
    self:showNone(arr:getSize() <= 0);
end

--选择英雄
function Lua_TowerLineupWindow:onHeroSelected(heroVo)
    local standIdx = self.data:getHeroStandIdx(heroVo.unique_id)
    if standIdx == nil then -- 未上阵
        standIdx = DataCenter.heroLineupData:getNullStandIdx(self.standType, self.heroDic, self.lineupIdx)
        if standIdx == nil then -- 上阵英雄已达上限
            OperateAlert.showLangValue(126300)
            return
        end

        local num = 0
        local arr = self.heroDic[self.lineupIdx]
        for i = 1, arr:getSize() do
            if arr[i] > 0 then
                num = num + 1
            end
        end
        if num == self.limit_num then --上阵英雄已达上限
            OperateAlert.showLangValue(126300);
            return
        end

        local lineupIdx = self.data:getHeroLineupIdx(heroVo.id)
        if lineupIdx then
            if lineupIdx == self.lineupIdx then
                OperateAlert.showLangValue(126302)
            else
                OperateAlert.show(LanUtil.formateStr(126325, convert_arab_to_chinese(lineupIdx)))
            end
            return
        end
        
        if heroVo.trial_state then
            local trialLineupLimit = DataCenter.heroData:trialHeroLineup(self.lineupType); -- 试用英雄上阵限制
            local trialTowerLimit = DataCenter.heroData:isClimbLimit(heroVo.unique_id, self.showData.id); -- 试用英雄爬塔次数限制
            if trialLineupLimit and trialTowerLimit == false then
                OperateAlert.show(LanUtil.formateStr(201017, heroVo.name));
                return;
            end
        end

        self.data:setHeroById(self.lineupIdx, standIdx, heroVo.unique_id)
    else
        self.data:setHeroById(self.lineupIdx, standIdx, 0)
    end

    self:updateHeroSelected();
    self:updateSceneModel();
    self:updateLineupNum();
    self:updateAureoleInfo();
end

--一键上阵
function Lua_TowerLineupWindow:onOneBtnClick(go)
    local arr = DataCenter.heroLineupData:getHeroListByCampDic(0, 0, self.campLimitDic, self.lineupType, self.lineupIdx, 1);
    DataCenter.heroLineupData:setHeroOneKey(self.standType, self.heroDic, self.lineupIdx, self.lineupType, arr, self.limit_num);

    self.data:initLineUpInfo();
    self:updateHeroSelected();
    self:updateSceneModel();
    self:updateLineupNum();
    self:updateAureoleInfo();
end

function Lua_TowerLineupWindow:checkLineupIsFull(lineupIdx)
    local num = self.data:getHeroNumByLineupIdx(lineupIdx);
    if num < self.limit_num then
        local arr = DataCenter.heroLineupData:getHeroListByCampDic(0, 0, self.campLimitDic, self.lineupType, lineupIdx, 1);
        if DataCenter.heroLineupData:checkPackHaveHero(self.lineupType, arr) then
            local tipsData = { des = 126312, btnType = 1, cancelLabel = 126328, owner = self, sureFun = self.onFight }
            Lua_WindowUtil.openWin("Lua_TipsWindow", Lua_WinParam.ACTION_OPEN, tipsData)
            return true;
        end
    end

    if self.showData.camp > 0 then
        local arr = self.heroDic[lineupIdx];
        local campType;
        for i = 1, arr:getSize() do
            if arr[i] > 0 then
                campType = DataCenter.heroData:getItemByUniqueId(arr[i]).campType;
                if self.campLimitDic[campType] == nil then
                    OperateAlert.showLangValue(201019);
                    return true;
                end
            end
        end
    end

    return false;
end

function Lua_TowerLineupWindow:onTrialLimitTip()
    local arr = self.data:getHeroArr(self.lineupIdx);
    local heroVo;

    local trialLineupLimit = DataCenter.heroData:trialHeroLineup(self.lineupType); -- 试用英雄是否能上阵
    local trialTowerLimit; -- 试用英雄爬塔次数限制
    local towerType = self.showData.id;
    local towerVo = DataCenter.climbTowerData:getTowerVoById(towerType);
    local limitNum = DataCenter.heroData:trialTowerlimit(towerType);
    local count;
    local str;
    for i = 1, arr:getSize() do
        if arr[i] > 0 then
            heroVo = DataCenter.heroData:getItemByUniqueId(arr[i]);
            if heroVo.trial_state and trialLineupLimit then
                trialTowerLimit, count = DataCenter.heroData:isClimbLimit(heroVo.unique_id, towerType);
                if trialTowerLimit and count ~= nil then
                    if str == nil then
                        str = LanUtil.formateStr(201018, heroVo.name, towerVo.name, count, limitNum);
                    else
                        str = str .. "\n" .. LanUtil.formateStr(201018, heroVo.name, towerVo.name, count, limitNum);
                    end
                elseif trialTowerLimit == false then
                    self:onHeroSelected(heroVo); -- 次数用完，自动下阵
                    return;
                end
            end
        end
    end

    if str ~= nil then
        if self.trialTipBg == nil then
            self.trialTipBg = UICreate.createUIAtlasImage(self.content, "new_hero_atlas_2", "xui_xz_widget_13", -360, -125, 0, 0);
            self.trialTipBg.pivotValue = 0;
            self.trialTipBg.anchorValue = 1;

            self.trialTipTxt = UICreate.createLabel(self.content, "", -350, -128, 100, 40, 22);
            self.trialTipTxt.horizontalOverflowValue = 1;
            self.trialTipTxt.verticalOverflowValue = 1;
            self.trialTipTxt.pivotValue = 0;
            self.trialTipTxt.anchorValue = 1;
        end
        self.trialTipBg:setEnable(true);
        self.trialTipTxt.text = str;
    else
        if self.trialTipBg ~= nil then
            self.trialTipBg:setEnable(false);
            self.trialTipTxt.text = "";
        end
    end
end
























Lua_TowerLineupCell = class("Lua_TowerLineupCell", Lua_HeroLineupCell);

function Lua_TowerLineupCell:setCustomParam(customParam)
    self.customParam = customParam;
    self.curLineupType = Mathf.Floor(customParam / 10000);
    self.curLineupIdx = Mathf.Floor(customParam / 100 % 10);
    self.curTowerId = customParam % 10;
end

function Lua_TowerLineupCell:setData(data)
    self.data = DataCenter.heroData:getItemByUniqueId(data);
    self.itemIcon:setData(self.data);

    self.trialLineupLimit = nil; -- 试用英雄上阵限制
    self.trialTowerLimit = nil; -- 试用英雄爬塔次数限制
    if self.data.trial_state then
        self.trialLineupLimit = DataCenter.heroData:trialHeroLineup(self.curLineupType);
        self.trialTowerLimit = DataCenter.heroData:isClimbLimit(self.data.unique_id, self.curTowerId);
    end

    local state = self.trialLineupLimit == false or (self.trialLineupLimit and self.trialTowerLimit == false);
    self.itemIcon:setMask(state);
    self.itemIcon:setLock(state);
    self:updateSelected();
end

function Lua_TowerLineupCell:onPressClick()
    if self.trialLineupLimit == false then
        OperateAlert.show(LanUtil.formateStr(201020, self.data.name));
        return;
    end

    if self.lineupIdx and self.lineupIdx ~= self.curLineupIdx then
        OperateAlert.show(LanUtil.formateStr(126325, convert_arab_to_chinese(self.lineupIdx)))
        return
    end

    Lua_MsgUtil.callFunc("TOWER_LINEUP_HERO_SELECT", self.data);
end
